==> ViennaCL-1.6.1.tar.gz: ViennaCL-1.6.1/doc/html/dir_35f9be625259f60231ebff5b0d077ea2.js <==
var dir_35f9be625259f60231ebff5b0d077ea2 =
[
    [ "amg.cpp", "amg_8cpp.html", null ],
    [ "bandwidth-reduction.cpp", "bandwidth-reduction_8cpp.html", null ],
    [ "bisect.cpp", "examples_2tutorial_2bisect_8cpp.html", null ],
    [ "blas1.cpp", "examples_2tutorial_2blas1_8cpp.html", null ],
    [ "blas2.cpp", "examples_2tutorial_2blas2_8cpp.html", null ],
    [ "blas3.cpp", "examples_2tutorial_2blas3_8cpp.html", "examples_2tutorial_2blas3_8cpp" ],
    [ "blas3range.cpp", "blas3range_8cpp.html", "blas3range_8cpp" ],
    [ "custom-context.cpp", "custom-context_8cpp.html", null ],
    [ "custom-kernels.cpp", "custom-kernels_8cpp.html", null ],
    [ "eigen-with-viennacl.cpp", "eigen-with-viennacl_8cpp.html", null ],
    [ "fft.cpp", "fft_8cpp.html", null ],
    [ "iterative-eigen.cpp", "iterative-eigen_8cpp.html", null ],
    [ "iterative-mtl4.cpp", "iterative-mtl4_8cpp.html", null ],
    [ "iterative-ublas.cpp", "iterative-ublas_8cpp.html", null ],
    [ "iterative.cpp", "iterative_8cpp.html", null ],
    [ "lanczos.cpp", "lanczos_8cpp.html", null ],
    [ "least-squares.cpp", "least-squares_8cpp.html", "least-squares_8cpp" ],
    [ "libviennacl.cpp", "libviennacl_8cpp.html", null ],
    [ "matrix-range.cpp", "matrix-range_8cpp.html", null ],
    [ "mtl4-with-viennacl.cpp", "mtl4-with-viennacl_8cpp.html", null ],
    [ "multithreaded.cpp", "multithreaded_8cpp.html", null ],
    [ "multithreaded_cg.cpp", "multithreaded__cg_8cpp.html", null ],
    [ "nmf.cpp", "examples_2tutorial_2nmf_8cpp.html", null ],
    [ "power-iter.cpp", "power-iter_8cpp.html", null ],
    [ "qr.cpp", "tutorial_2qr_8cpp.html", null ],
    [ "qr_method.cpp", "examples_2tutorial_2qr__method_8cpp.html", null ],
    [ "Random.hpp", "examples_2tutorial_2_random_8hpp.html", "examples_2tutorial_2_random_8hpp" ],
    [ "scheduler.cpp", "tutorial_2scheduler_8cpp.html", null ],
    [ "scheduler_matrix.cpp", "examples_2tutorial_2scheduler__matrix_8cpp.html", "examples_2tutorial_2scheduler__matrix_8cpp" ],
    [ "spai.cpp", "spai_8cpp.html", null ],
    [ "sparse.cpp", "examples_2tutorial_2sparse_8cpp.html", null ],
    [ "structured-matrices.cpp", "examples_2tutorial_2structured-matrices_8cpp.html", null ],
    [ "tql2.cpp", "tql2_8cpp.html", null ],
    [ "vector-io.hpp", "vector-io_8hpp.html", "vector-io_8hpp" ],
    [ "vector-range.cpp", "vector-range_8cpp.html", null ],
    [ "viennacl-info.cpp", "viennacl-info_8cpp.html", null ],
    [ "wrap-host-buffer.cpp", "wrap-host-buffer_8cpp.html", null ]
];

==> ViennaCL-1.7.0.tar.gz: ViennaCL-1.7.0/doc/html/dir_35f9be625259f60231ebff5b0d077ea2.js <==
var dir_35f9be625259f60231ebff5b0d077ea2 =
[
    [ "amg.cpp", "amg_8cpp.html", null ],
    [ "armadillo-with-viennacl.cpp", "armadillo-with-viennacl_8cpp.html", null ],
    [ "bandwidth-reduction.cpp", "bandwidth-reduction_8cpp.html", null ],
    [ "bisect.cpp", "examples_2tutorial_2bisect_8cpp.html", null ],
    [ "blas1.cpp", "examples_2tutorial_2blas1_8cpp.html", null ],
    [ "blas2.cpp", "examples_2tutorial_2blas2_8cpp.html", null ],
    [ "blas3.cpp", "examples_2tutorial_2blas3_8cpp.html", "examples_2tutorial_2blas3_8cpp" ],
    [ "blas3range.cpp", "blas3range_8cpp.html", "blas3range_8cpp" ],
    [ "custom-context.cpp", "custom-context_8cpp.html", null ],
    [ "custom-kernels.cpp", "custom-kernels_8cpp.html", null ],
    [ "eigen-with-viennacl.cpp", "eigen-with-viennacl_8cpp.html", null ],
    [ "fft.cpp", "fft_8cpp.html", null ],
    [ "iterative-armadillo.cpp", "iterative-armadillo_8cpp.html", null ],
    [ "iterative-custom.cpp", "iterative-custom_8cpp.html", null ],
    [ "iterative-eigen.cpp", "iterative-eigen_8cpp.html", null ],
    [ "iterative-mtl4.cpp", "iterative-mtl4_8cpp.html", null ],
    [ "iterative-ublas.cpp", "iterative-ublas_8cpp.html", null ],
    [ "iterative.cpp", "iterative_8cpp.html", null ],
    [ "lanczos.cpp", "lanczos_8cpp.html", null ],
    [ "least-squares.cpp", "least-squares_8cpp.html", "least-squares_8cpp" ],
    [ "libviennacl.cpp", "libviennacl_8cpp.html", null ],
    [ "matrix-free.cpp", "matrix-free_8cpp.html", null ],
    [ "matrix-range.cpp", "matrix-range_8cpp.html", null ],
    [ "mtl4-with-viennacl.cpp", "mtl4-with-viennacl_8cpp.html", null ],
    [ "multithreaded.cpp", "multithreaded_8cpp.html", null ],
    [ "multithreaded_cg.cpp", "multithreaded__cg_8cpp.html", null ],
    [ "nmf.cpp", "examples_2tutorial_2nmf_8cpp.html", null ],
    [ "power-iter.cpp", "power-iter_8cpp.html", null ],
    [ "qr.cpp", "tutorial_2qr_8cpp.html", null ],
    [ "qr_method.cpp", "examples_2tutorial_2qr__method_8cpp.html", null ],
    [ "scheduler.cpp", "tutorial_2scheduler_8cpp.html", null ],
    [ "spai.cpp", "spai_8cpp.html", null ],
    [ "sparse.cpp", "examples_2tutorial_2sparse_8cpp.html", null ],
    [ "structured-matrices.cpp", "examples_2tutorial_2structured-matrices_8cpp.html", null ],
    [ "tql2.cpp", "tql2_8cpp.html", null ],
    [ "vector-io.hpp", "vector-io_8hpp.html", "vector-io_8hpp" ],
    [ "vector-range.cpp", "vector-range_8cpp.html", null ],
    [ "viennacl-info.cpp", "viennacl-info_8cpp.html", null ],
    [ "wrap-host-buffer.cpp", "wrap-host-buffer_8cpp.html", null ]
];
